==> fifechan_0.1.3.orig.tar.gz: fifechan-0.1.3/src/size.cpp <==
/***************************************************************************
 *   Copyright (c) 2016 by the fifechan team                               *
 *   https://github.com/fifengine/fifechan                                 *
 *   This file is part of fifechan.                                        *
 *                                                                         *
 *   fifechan is free software; you can redistribute it and/or             *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
 ***************************************************************************/

/*
 * For comments regarding functions please see the header file.
 */

#include "fifechan/size.hpp"

namespace fcn
{
    Size::Size(int width, int height)
    :
    mWidth(width),
    mHeight(height)
    {
    }
    
    Size::~Size()
    {
    }
    
    int Size::getWidth() const
    {
        return mWidth;
    }
    
    int Size::getHeight() const
    {
        return mHeight;
    }
    
    void Size::setWidth(int width)
    {
        mWidth = width;
    }
    
    void Size::setHeight(int height)
    {
        mHeight = height;
    }
};

==> fifechan_0.1.5.orig.tar.gz: fifechan-0.1.5/src/size.cpp <==
/***************************************************************************
 *   Copyright (C) 2012-2019 by the fifechan team                          *
 *   http://fifechan.github.com/fifechan                                   *
 *   This file is part of fifechan.                                        *
 *                                                                         *
 *   fifechan is free software; you can redistribute it and/or             *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
 ***************************************************************************/

#include "fifechan/size.hpp"

namespace fcn
{
    Size::Size(int width, int height):
        mWidth(width),
        mHeight(height) {
    }
    
    Size::~Size()
    {
    }
    
    int Size::getWidth() const
    {
        return mWidth;
    }
    
    int Size::getHeight() const
    {
        return mHeight;
    }
    
    void Size::setWidth(int width)
    {
        mWidth = width;
    }
    
    void Size::setHeight(int height)
    {
        mHeight = height;
    }
};
